/*
 * Segment 8 Parametrierung und Konfiguration, SWE 8.2 Parametrierung
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.puk.param.param;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.puk.param.lib.DatenSchreibenException;
import de.bsvrz.puk.param.lib.Parameter;
import de.bsvrz.puk.param.lib.ParameterInfo;

/**
 * Schreibt und liest persistente Datensätze.
 *
 * @author BitCtrl Systems GmbH, Peuker, Schumann
 */
public interface Persistenz {

	/** bereinigt die Daten des Persistenzmoduls. */
	void aufraeumen();

	/** erstellt ein Backup der Datenbank. */
	void backup();

	/** schließt die Persistenz und gibt eventuell belegte Ressourcen frei. */
	void close();

	/**
	 * entfernt die gespeicherten Daten für die &uuml;bergebene Identifikation.
	 *
	 * @param parameter
	 *            Identifikation des gesuchten Datensatzen
	 * @throws DatenSchreibenException
	 *             die Daten konnten nicht gespeichert werden
	 */
	void entferne(ParameterInfo parameter) throws DatenSchreibenException;

	/**
	 * entfernt die gespeicherten Daten für die übergebene Simulationsvariante.
	 *
	 * @param simulationsVariante
	 *            die Simulationsvariante
	 */
	void entferneSimulation(short simulationsVariante);

	/**
	 * erzeugt eine Kopie der gespeicherten Parameterdaten für die angegebene
	 * Simulationsvariante.
	 *
	 * @param simulationsVariante
	 *            die Simulationsvariante
	 */
	void erzeugeSimulation(short simulationsVariante);

	/**
	 * initialisiert das Persistenzobjekt mit dem übergebenen
	 * Verbindungsparameter und der Datenverteilerverbindung.
	 *
	 * @param verbindung
	 *            die verwendete Datenverteilerverbindung
	 * @param parameter
	 *            der Parameter
	 */
	void initalisiere(ClientDavInterface verbindung, PersistenzParameter parameter);

	/**
	 * Liest einen persistenten Datensatz und liefert ihn zurück.
	 *
	 * @param parameter
	 *            Identifiation des gesuchten Datensatzen
	 * @return Gesicherter Datensatz oder <code>null</code>, wenn kein Datensatz
	 *         mit der Identifikation existiert
	 */
	Parameter lies(ParameterInfo parameter);

	/**
	 * Schreibt einen Datensatz persistent.
	 *
	 * @param parameter
	 *            Zu sichernder Parameter
	 * @throws DatenSchreibenException
	 *             die Daten konnten nicht gespeichert werden
	 */
	void schreibe(Parameter parameter) throws DatenSchreibenException;

	/**
	 * entfernt alle persitenten Datensätze die nicht merh versorgt werden.
	 *
	 * @param parameterProvider
	 *            die Menge der versorgten Datensätze
	 */
	void cleanup(ParameterProvider parameterProvider);
}
