/*
 * Segment 8 Parametrierung und Konfiguration, SWE 8.2 Parametrierung
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.puk.param.simulation;

/**
 * Der Zustand einer Simulation.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
enum SimulationsStatus {

	/**
	 * der Zustand ist nicht definiert, d.h. es wurden keine Daten zu der
	 * entsprechenden Attributgruppe gefunden.
	 */
	UNDEFINIERT(-1, "undefiniert"),

	/**
	 * ein neues Simulationsobjekt wurde angelegt.
	 */
	NEU(0, "Neu"),

	/**
	 * Vor dem eigentlichen Start einer Simulation.
	 */
	VORSTART(1, "Vorstart"),

	/**
	 * Start der Simulation; ist erst möglich, wenn der Vorstart erfolgreich
	 * war.
	 */
	START(2, "Start"),

	/**
	 * Stop der Simulation.
	 */
	STOP(3, "Stop"),

	/**
	 * Löschen der Simulation; führt dazu, dass das Simulationsobjekt gelöscht
	 * wird und die Simulationsvariante von einer anderen Simulation benutzt
	 * werden kann.
	 */
	GELOESCHT(4, "gelöscht"),

	/**
	 * Pause.
	 */
	PAUSE(5, "Pause");

	/**
	 * liefert den durch den übergebenen Code beschriebenen Zustand.<br>
	 * Ist kein Zustand definiert ist das Ergebnis der Zustand UNDEFINIERT.
	 *
	 * @param code
	 *            der Code des gesuchten Zustandes
	 * @return der Zustand (Standardwert: UNDEFINIERT)
	 */
	static SimulationsStatus getStatus(final int code) {
		SimulationsStatus result = UNDEFINIERT;
		for (final SimulationsStatus suche : SimulationsStatus.values()) {
			if (suche.getCode() == code) {
				result = suche;
				break;
			}
		}

		return result;
	}

	/** der dem Zustand zugeordnete Code. */
	private int code;

	/** der dem Zustand zugeordnete Name. */
	private String name;

	/**
	 * Standardkonstruktor.
	 *
	 * @param code
	 *            der Code
	 * @param name
	 *            der Name des Zustandes
	 */
	SimulationsStatus(final int code, final String name) {
		this.code = code;
		this.name = name;
	}

	public Integer getCode() {
		return code;
	}

	public String getName() {
		return name;
	}
}
